pub struct ApSource {
pub media_type: String,
pub content: String,
}Expand description
Original source format for content that was converted from another format.
This structure is used to preserve the original source content (e.g., Markdown)
when content is converted to HTML for the content field. This allows clients
to retrieve the original format for editing without reverse-engineering from HTML.
Examples
use jdt_activity_pub::ApSource;
let source = ApSource {
media_type: "text/markdown".to_string(),
content: "# Hello\n\nThis is **bold** text.".to_string(),
};Fields
media_type: StringThe media type of the original source format (e.g., “text/markdown”, “text/plain”)
content: StringThe original content in its source format